@@ -2,14 +2,20 @@ use serde::{Deserialize, Serialize};
 
 use super::nix::Pkg;
 
+// Debian 11
+static DEFAULT_BASE_IMAGE: &str = "ghcr.io/railwayapp/nixpacks:debian-1652414952";
+
 #[serde_with::skip_serializing_none]
-#[derive(Serialize, Deserialize, Default, Clone, Debug)]
+#[derive(Serialize, Deserialize, Clone, Debug)]
 pub struct SetupPhase {
     pub pkgs: Vec<Pkg>,
     pub archive: Option<String>,
 
     #[serde(rename = "onlyIncludeFiles")]
     pub only_include_files: Option<Vec<String>>,
+
+    #[serde(rename = "baseImage")]
+    pub base_image: String,
 }
 
 impl SetupPhase {
@@ -18,6 +24,7 @@ impl SetupPhase {
             pkgs,
             archive: None,
             only_include_files: None,
+            base_image: DEFAULT_BASE_IMAGE.to_string(),
         }
     }
 
@@ -39,6 +46,17 @@ impl SetupPhase {
     }
 }
 
+impl Default for SetupPhase {
+    fn default() -> Self {
+        Self {
+            pkgs: Default::default(),
+            archive: Default::default(),
+            only_include_files: Default::default(),
+            base_image: DEFAULT_BASE_IMAGE.to_string(),
+        }
+    }
+}
+
 #[serde_with::skip_serializing_none]
 #[derive(Serialize, Deserialize, Default, Clone, Debug)]
 pub struct InstallPhase {
@@ -109,10 +127,24 @@ impl BuildPhase {
 #[derive(Serialize, Deserialize, Default, Clone, Debug)]
 pub struct StartPhase {
     pub cmd: Option<String>,
+
+    #[serde(rename = "runImage")]
+    pub run_image: Option<String>,
 }
 
 impl StartPhase {
     pub fn new(cmd: String) -> Self {
-        Self { cmd: Some(cmd) }
+        Self {
+            cmd: Some(cmd),
+            run_image: None,
+        }
+    }
+
+    pub fn run_in_image(&mut self, image_name: String) {
+        self.run_image = Some(image_name);
+    }
+
+    pub fn run_in_default_image(&mut self) {
+        self.run_image = Some(DEFAULT_BASE_IMAGE.to_string());
     }
 }
