@@ -35,14 +35,14 @@ impl Provider for RustProvider {
         Ok(app.includes_file("Cargo.toml"))
     }
 
-    fn setup(&self, app: &App, _env: &Environment) -> Result<Option<SetupPhase>> {
-        let rust_pkg: Pkg = self.get_rust_pkg(app)?;
+    fn setup(&self, app: &App, env: &Environment) -> Result<Option<SetupPhase>> {
+        let rust_pkg: Pkg = RustProvider::get_rust_pkg(app, env)?;
 
         let mut setup_phase =
             SetupPhase::new(vec![Pkg::new("gcc"), rust_pkg.from_overlay(RUST_OVERLAY)]);
 
         // Include the rust toolchain file so we can install that rust version with Nix
-        if let Some(toolchain_file) = self.get_rust_toolchain_file(app)? {
+        if let Some(toolchain_file) = RustProvider::get_rust_toolchain_file(app)? {
             setup_phase.add_file_dependency(toolchain_file);
         }
 
@@ -54,7 +54,7 @@ impl Provider for RustProvider {
     }
 
     fn start(&self, app: &App, _env: &Environment) -> Result<Option<StartPhase>> {
-        if let Some(toml_file) = self.parse_cargo_toml(app)? {
+        if let Some(toml_file) = RustProvider::parse_cargo_toml(app)? {
             let name = toml_file.package.name;
             Ok(Some(StartPhase::new(format!("./target/release/{}", name))))
         } else {
@@ -74,7 +74,7 @@ impl Provider for RustProvider {
 }
 
 impl RustProvider {
-    fn parse_cargo_toml(&self, app: &App) -> Result<Option<CargoToml>> {
+    fn parse_cargo_toml(app: &App) -> Result<Option<CargoToml>> {
         if app.includes_file("Cargo.toml") {
             let cargo_toml: CargoToml =
                 app.read_toml("Cargo.toml").context("Reading Cargo.toml")?;
@@ -84,7 +84,7 @@ impl RustProvider {
         Ok(None)
     }
 
-    fn get_rust_toolchain_file(&self, app: &App) -> Result<Option<String>> {
+    fn get_rust_toolchain_file(app: &App) -> Result<Option<String>> {
         if app.includes_file("rust-toolchain") {
             Ok(Some("rust-toolchain".to_string()))
         } else if app.includes_file("rust-toolchain.toml") {
@@ -95,14 +95,20 @@ impl RustProvider {
     }
 
     // Get the rust package version by parsing the `rust-version` field in `Cargo.toml`
-    fn get_rust_pkg(&self, app: &App) -> Result<Pkg> {
-        if let Some(toolchain_file) = self.get_rust_toolchain_file(app)? {
+    fn get_rust_pkg(app: &App, env: &Environment) -> Result<Pkg> {
+        if let Some(version) = env.get_config_variable("RUST_VERSION") {
+            return Ok(Pkg::new(
+                format!("rust-bin.stable.\"{}\".default", version).as_str(),
+            ));
+        }
+
+        if let Some(toolchain_file) = RustProvider::get_rust_toolchain_file(app)? {
             return Ok(Pkg::new(
                 format!("(rust-bin.fromRustupToolchainFile ./{})", toolchain_file).as_str(),
             ));
         }
 
-        let pkg = match self.parse_cargo_toml(app)? {
+        let pkg = match RustProvider::parse_cargo_toml(app)? {
             Some(toml_file) => {
                 let version = toml_file.package.rust_version;
 
@@ -118,3 +124,67 @@ impl RustProvider {
         Ok(pkg)
     }
 }
+
+#[cfg(test)]
+mod test {
+    use std::collections::HashMap;
+
+    use crate::nixpacks::{app::App, environment::Environment, nix::Pkg};
+
+    use super::*;
+
+    #[test]
+    fn test_no_version() -> Result<()> {
+        assert_eq!(
+            RustProvider::get_rust_pkg(
+                &App::new("./examples/rust-rocket")?,
+                &Environment::default()
+            )?,
+            Pkg::new(DEFAULT_RUST_PACKAGE)
+        );
+
+        Ok(())
+    }
+
+    #[test]
+    fn test_custom_version() -> Result<()> {
+        assert_eq!(
+            RustProvider::get_rust_pkg(
+                &App::new("./examples/rust-custom-version")?,
+                &Environment::default()
+            )?,
+            Pkg::new("rust-bin.stable.\"1.56.0\".default")
+        );
+
+        Ok(())
+    }
+
+    #[test]
+    fn test_toolchain_file() -> Result<()> {
+        assert_eq!(
+            RustProvider::get_rust_pkg(
+                &App::new("./examples/rust-custom-toolchain")?,
+                &Environment::default()
+            )?,
+            Pkg::new("(rust-bin.fromRustupToolchainFile ./rust-toolchain.toml)")
+        );
+
+        Ok(())
+    }
+
+    #[test]
+    fn test_version_from_environment_variable() -> Result<()> {
+        assert_eq!(
+            RustProvider::get_rust_pkg(
+                &App::new("./examples/rust-custom-toolchain")?,
+                &Environment::new(HashMap::from([(
+                    "NIXPACKS_RUST_VERSION".to_string(),
+                    "1.54.0".to_string()
+                )]))
+            )?,
+            Pkg::new("rust-bin.stable.\"1.54.0\".default")
+        );
+
+        Ok(())
+    }
+}
